@@ -4,8 +4,8 @@ import unittest
 
 class UTMTestCase(unittest.TestCase):
     def assert_utm_equal(self, a, b):
-        self.assertAlmostEqual(a[0], b[0], -1)
-        self.assertAlmostEqual(a[1], b[1], -1)
+        self.assertAlmostEqual(a[0], b[0], 0)
+        self.assertAlmostEqual(a[1], b[1], 0)
         self.assertEqual(a[2], b[2])
         self.assertEqual(a[3].upper(), b[3].upper())
 
@@ -22,7 +22,7 @@ class KnownValues(UTMTestCase):
         ((40.71435, -74.00597), (583960, 4507523, 18, 'T')),
         # Wellington, New Zealand
         ((-41.28646, 174.77624), (313784, 5427057, 60, 'G')),
-        # Capetown, South Africe
+        # Capetown, South Africa
         ((-33.92487, 18.42406), (261878, 6243186, 34, 'H')),
         # Mendoza, Argentina
         ((-32.89018, -68.84405), (514586, 6360877, 19, 'h')),
